﻿using System;

using DWORD = System.UInt32;
using LARGE_INTEGER = System.UInt64;

namespace Microsoft.Win32
{
	/// <summary>
	/// References a method to be called when progress is made during a file copy.
	/// </summary>
	/// <param name="copyFileProgress">A <see cref="CopyFileProgress"/> object describing progress of the file copy.</param>
	/// <param name="userData">User-defined data that was specified to be passed to the callback.</param>
	/// <returns>A <see cref="CopyFileProgressAction"/> indicating an action to take.</returns>
	public delegate CopyFileProgressAction CopyFileProgressCallback(CopyFileProgress copyFileProgress, object userData);

	internal static partial class Kernel32
	{
		/// <summary>
		/// An application-defined callback function used with the CopyFileEx, MoveFileTransacted, and MoveFileWithProgress functions. It is called when a portion of a copy or move operation is completed. The LPPROGRESS_ROUTINE type defines a pointer to this callback function. CopyProgressRoutine is a placeholder for the application-defined function name.
		/// </summary>
		/// <param name="TotalFileSize">The total size of the file, in bytes.</param>
		/// <param name="TotalBytesTransferred">The total number of bytes transferred from the source file to the destination file since the copy operation began.</param>
		/// <param name="StreamSize">The total size of the current file stream, in bytes.</param>
		/// <param name="StreamBytesTransferred">The total number of bytes in the current stream that have been transferred from the source file to the destination file since the copy operation began.</param>
		/// <param name="dwStreamNumber">A handle to the current stream. The first time CopyProgressRoutine is called, the stream number is 1.</param>
		/// <param name="dwCallbackReason">The reason that CopyProgressRoutine was called.</param>
		/// <param name="hSourceFile">A handle to the source file.</param>
		/// <param name="hDestinationFile">A handle to the destination file.</param>
		/// <param name="lpData">Argument passed to CopyProgressRoutine by CopyFileEx, MoveFileTransacted, or MoveFileWithProgress.</param>
		/// <returns>The CopyProgressRoutine function should return one of the following values.
		/// PROGRESS_CANCEL - Cancel the copy operation and delete the destination file.
		/// PROGRESS_CONTINUE - Continue the copy operation.
		/// PROGRESS_QUIET - Continue the copy operation, but stop invoking CopyProgressRoutine to report progress.
		/// PROGRESS_STOP - Stop the copy operation. It can be restarted at a later time.
		/// </returns>
		/// http://msdn.microsoft.com/en-us/library/windows/desktop/aa363854(v=vs.85).aspx
		/// <![CDATA[DWORD CALLBACK CopyProgressRoutine(_In_ LARGE_INTEGER TotalFileSize, _In_ LARGE_INTEGER TotalBytesTransferred, _In_ LARGE_INTEGER StreamSize, _In_LARGE_INTEGER StreamBytesTransferred, _In_ DWORD dwStreamNumber, _In_ DWORD dwCallbackReason, _In_ HANDLE hSourceFile, _In_ HANDLE hDestinationFile, _In_opt_ LPVOID lpData);]]>
		internal delegate CopyFileProgressAction CopyProgressRoutine(LARGE_INTEGER TotalFileSize, LARGE_INTEGER TotalBytesTransferred, LARGE_INTEGER StreamSize, LARGE_INTEGER StreamBytesTransferred, DWORD dwStreamNumber, CopyFileProgressCallbackReason dwCallbackReason, IntPtr hSourceFile, IntPtr hDestinationFile, IntPtr lpData);
	}
}