﻿namespace Microsoft.Win32
{
	/// <summary>
	/// Indicates the action to take during copy file progress.
	/// </summary>
	public enum CopyFileProgressAction : uint
	{
		/// <summary>
		/// Indicates that CopyFileEx should continue the copy operation.
		/// </summary>
		Continue = Kernel32.PROGRESS_CONTINUE,

		/// <summary>
		/// Indicates that CopyFileEx should cancel the copy operation and delete the destination file.
		/// </summary>
		Cancel = Kernel32.PROGRESS_CANCEL,

		/// <summary>
		/// Indicates that CopyFileEx should stop the copy operation. It can be restarted at a later time.
		/// </summary>
		Stop = Kernel32.PROGRESS_STOP,

		/// <summary>
		/// Indicates that CopyFileEx should continue the copy operation, but stop invoking CopyProgressRoutine to report progress.
		/// </summary>
		Quiet = Kernel32.PROGRESS_QUIET,
	}

	/// <summary>
	/// Indicates the reason CopyProgressRoutine was called.
	/// </summary>
	internal enum CopyFileProgressCallbackReason : uint
	{
		/// <summary>
		/// Another part of the data file was copied.
		/// </summary>
		ChunkFinished = Kernel32.CALLBACK_CHUNK_FINISHED,

		/// <summary>
		/// Another stream was created and is about to be copied. This is the callback reason given when the callback routine is first invoked.
		/// </summary>
		StreamSwitch = Kernel32.CALLBACK_STREAM_SWITCH,
	}
}