﻿using System;
using System.Runtime.InteropServices;

using DWORD = System.UInt32;

namespace Microsoft.Win32
{
	/// <summary>
	/// Contains information about the file that is found by the FindFirstFile, FindFirstFileEx, or FindNextFile function.
	/// </summary>
	[StructLayout(LayoutKind.Sequential, CharSet = CharSet.Auto)]
	internal struct WIN32_FIND_DATA
	{
		/// <summary>
		/// The file attributes of a file.
		/// </summary>
		public DWORD dwFileAttributes;

		/// <summary>
		/// A <see cref="System.Runtime.InteropServices.ComTypes.FILETIME"/> structure that specifies when a file or directory was created.
		/// 
		/// If the underlying file system does not support creation time, this member is zero.
		/// </summary>
		public System.Runtime.InteropServices.ComTypes.FILETIME ftCreationTime;

		/// <summary>
		/// A <see cref="System.Runtime.InteropServices.ComTypes.FILETIME"/> structure.
		/// 
		/// For a file, the structure specifies when the file was last read from, written to, or for executable files, run.
		/// 
		/// For a directory, the structure specifies when the directory is created. If the underlying file system does not support last access time, this member is zero.
		/// 
		/// On the FAT file system, the specified date for both files and directories is correct, but the time of day is always set to midnight.
		/// </summary>
		public System.Runtime.InteropServices.ComTypes.FILETIME ftLastAccessTime;

		/// <summary>
		/// A <see cref="System.Runtime.InteropServices.ComTypes.FILETIME"/> structure.
		/// 
		/// For a file, the structure specifies when the file was last written to, truncated, or overwritten, for example, when WriteFile or SetEndOfFile are used. The date and time are not updated when file attributes or security descriptors are changed.
		/// 
		/// For a directory, the structure specifies when the directory is created. If the underlying file system does not support last write time, this member is zero.
		/// </summary>
		public System.Runtime.InteropServices.ComTypes.FILETIME ftLastWriteTime;

		/// <summary>
		/// The high-order DWORD value of the file size, in bytes.
		/// 
		/// This value is zero unless the file size is greater than MAXDWORD.
		/// 
		/// The size of the file is equal to (nFileSizeHigh * (MAXDWORD+1)) + nFileSizeLow.
		/// </summary>
		public DWORD nFileSizeHigh;

		/// <summary>
		/// The low-order DWORD value of the file size, in bytes.
		/// </summary>
		public DWORD nFileSizeLow;

		/// <summary>
		/// If the dwFileAttributes member includes the FILE_ATTRIBUTE_REPARSE_POINT attribute, this member specifies the reparse point tag.
		/// 
		/// Otherwise, this value is undefined and should not be used.
		/// </summary>
		public DWORD dwReserved0;

		/// <summary>
		/// Reserved for future use.
		/// </summary>
		public DWORD dwReserved1;

		/// <summary>
		/// The name of the file.
		/// </summary>
		[MarshalAs(UnmanagedType.ByValTStr, SizeConst = 260)]
		public string cFileName;

		/// <summary>
		/// An alternative name for the file.
		/// 
		/// This name is in the classic 8.3 file name format.
		/// </summary>
		[MarshalAs(UnmanagedType.ByValTStr, SizeConst = 14)]
		public string cAlternateFileName;
	}
}